# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from chat_server_connector_v2.models.ai_usage_log_read import AiUsageLogRead

class TestAiUsageLogRead(unittest.TestCase):
    """AiUsageLogRead unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AiUsageLogRead:
        """Test AiUsageLogRead
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AiUsageLogRead`
        """
        model = AiUsageLogRead()
        if include_optional:
            return AiUsageLogRead(
                event_type = 1,
                spend_type = '',
                mt_credits = 1.337,
                created_at = 56,
                mt_breakdown = chat_server_connector_v2.models.mt_breakdown.MtBreakdown(
                    text = 1.337, 
                    voice = 1.337, 
                    image = 1.337, 
                    video = 1.337, 
                    audio = 1.337, )
            )
        else:
            return AiUsageLogRead(
                event_type = 1,
                spend_type = '',
                mt_credits = 1.337,
                created_at = 56,
        )
        """

    def testAiUsageLogRead(self):
        """Test AiUsageLogRead"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from chat_server_connector_v2.models.chat_message_attachment_read import ChatMessageAttachmentRead
from chat_server_connector_v2.models.chat_message_type import ChatMessageType
from chat_server_connector_v2.models.schedule_kind import ScheduleKind
from chat_server_connector_v2.models.scheduled_message_status import ScheduledMessageStatus
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class ScheduledMessageGet(BaseModel):
    """
    ScheduledMessageGet
    """ # noqa: E501
    id: StrictInt
    chat_id: StrictInt
    chat_member_id: StrictInt
    text: StrictStr
    file_id: Optional[StrictStr] = None
    chat_message_type: ChatMessageType
    schedule_kind: ScheduleKind
    cron_expr: Optional[StrictStr] = None
    timezone: Optional[StrictStr] = None
    next_run_at: StrictInt
    status: ScheduledMessageStatus
    last_run_at: Optional[StrictInt] = None
    last_error: Optional[StrictStr] = None
    created_at: StrictInt
    attachments: Optional[List[ChatMessageAttachmentRead]] = None
    __properties: ClassVar[List[str]] = ["id", "chat_id", "chat_member_id", "text", "file_id", "chat_message_type", "schedule_kind", "cron_expr", "timezone", "next_run_at", "status", "last_run_at", "last_error", "created_at", "attachments"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ScheduledMessageGet from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in attachments (list)
        _items = []
        if self.attachments:
            for _item_attachments in self.attachments:
                if _item_attachments:
                    _items.append(_item_attachments.to_dict())
            _dict['attachments'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ScheduledMessageGet from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "chat_id": obj.get("chat_id"),
            "chat_member_id": obj.get("chat_member_id"),
            "text": obj.get("text"),
            "file_id": obj.get("file_id"),
            "chat_message_type": obj.get("chat_message_type"),
            "schedule_kind": obj.get("schedule_kind"),
            "cron_expr": obj.get("cron_expr"),
            "timezone": obj.get("timezone"),
            "next_run_at": obj.get("next_run_at"),
            "status": obj.get("status"),
            "last_run_at": obj.get("last_run_at"),
            "last_error": obj.get("last_error"),
            "created_at": obj.get("created_at"),
            "attachments": [ChatMessageAttachmentRead.from_dict(_item) for _item in obj["attachments"]] if obj.get("attachments") is not None else None
        })
        return _obj


